package tp.mesClasses;

/**
 * Une cellule contient une valeur et une rfrence vers son suivant
 * @author jub
 *
 * @param <X> le type des cellules
 */
public class Cellule<X> {
	/**
	 * La valeur contenue dans la cellule
	 */
	private X valeur;
	/**
	 * Une rfrence vers une autre cellule
	 */
	private Cellule<X> suivant;
	
	/**
	 * Construit une cellule vide
	 */
	public Cellule() {
		this.valeur = null;
		this.suivant = null;
	}

	/**
	 * Permet de savoir si une cellule est vide. Une cellule est vide ssi sa valeur et son suivant sont nuls
	 * @return true si la cellule est vide et false sinon
	 */
	public boolean estVide(){
		return this.valeur == null && this.suivant==null;
	}

	/**
	 * Permet de connatre le suivant d'une cellule
	 * @return la rfrence vers la cellule suivante
	 */
	public Cellule<X> getSuivant() {
		return suivant;
	}

	/**
	 * Permet de connatre la valeur contenue dans la cellule
	 * @return la valeur 
	 */
	public X getValeur() {
		return valeur;
	}

	/**
	 * Permet de modifier le suivant d'une cellule
	 * @param suivant la nouvelle rfrence vers la cellule suivante
	 */
	public void setSuivant(Cellule<X> suivant) {
		this.suivant = suivant;
	}
	
	/**
	 * Permet de modifier la valeur contenue dans la cellule
	 * @param valeur la nouvelle valeur
	 */
	public void setValeur(X valeur) {
		this.valeur = valeur;
	}

	@Override
	public String toString() {
		
		return "["+this.valeur+"]->"+this.suivant;
	} 
	
	
}
